import { Http } from '@zeedhi/core';

export class GraphicsController {
  public fillGraphicPie({ component }) {
    const props = component.options.props;
    const routeName = props.routeName;
    const seriesNameColumn = props.seriesNameColumn;
    const labelsNameColumn = props.labelsNameColumn;
    const sendObject = {
      filter: [],
    };
    
    if (props.idOrigem) {
      sendObject.filter.push(
        {
          name: 'IDORIGEM',
          operator: '=',
          value: props.idOrigem,
        },
      );
    }
    
    Http.post(`/${routeName}`, sendObject).then((response) => {
      /* eslint no-console: ["error", { allow: ["warn", "error", "info", "log"] }] */
      const data = response.data.dataset[routeName];
      const labels = [];
      const series = [];
      data.forEach((row) => { labels.push(row[labelsNameColumn]); series.push(row[seriesNameColumn]); });
      component.options.labels = labels;
      component.series = series;
      component.updateChart(component.options.labels);
      component.updateChart(component.series);
    });
  }
  
  public fillGraphicBar({ component }) {
    const props = component.options.props;
    const routeName = props.routeName;
    const xaxisNameColumn = props.xaxisNameColumn;
    const seriesProps = props.series;
    const sendObject = {
      filter: [],
    };
    
    if (props.idOrigem) {
      sendObject.filter.push(
        {
          name: 'IDORIGEM',
          operator: '=',
          value: props.idOrigem,
        },
      );
    }
    
    Http.post(`/${routeName}`, sendObject).then((response) => {
      /* eslint no-console: ["error", { allow: ["warn", "error", "info", "log"] }] */
      const data = response.data.dataset[routeName];
      const xaxis = [];
      const series = [];
      Object.keys(seriesProps).forEach((prop) => {
        series.push({
          name: seriesProps[prop].label,
          data: data.map((item) => item[prop]),
        });
      });
      
      data.forEach((row) => { xaxis.push(row[xaxisNameColumn]); });
      component.options.xaxis.categories = xaxis;
      component.series = series;
      component.updateChart(component.options.labels);
      component.updateChart(component.series);
    });
  }
}
